Peripheral access API for MSP432P401R microcontrollers (generated using svd2rust v0.24.1 ( ))
You can find an overview of the generated API here.
API features to be included in the next
svd2rust release can be generated by cloning the svd2rust repository, checking out the above commit, and running cargo doc --open.
Modules
- adc14
- ADC14
- aes256
- AES256
- captio0
- CAPTIO0
- captio1
- CAPTIO1
- comp_e0
- COMP_E0
- comp_e1
- COMP_E1
- crc32
- CRC32
- cs
- CS
- dio
- DIO
- dma
- DMA
- eusci_
a0 - EUSCI_A0
- eusci_
a1 - EUSCI_A1
- eusci_
a2 - EUSCI_A2
- eusci_
a3 - EUSCI_A3
- eusci_
b0 - EUSCI_B0
- eusci_
b1 - EUSCI_B1
- eusci_
b2 - EUSCI_B2
- eusci_
b3 - EUSCI_B3
- flctl
- FLCTL
- generic
- Common register and bit access and modify traits
- pcm
- PCM
- pmap
- PMAP
- pss
- PSS
- ref_a
- REF_A
- rstctl
- RSTCTL
- rtc_c
- RTC_C
- sysctl
- SYSCTL
- system_
control_ space - System Control Space for ARM core: SCnSCB, SCB, SysTick, NVIC, CoreDebug, MPU, FPU
- timer32
- TIMER32
- timer_
a0 - TIMER_A0
- timer_
a1 - TIMER_A1
- timer_
a2 - TIMER_A2
- timer_
a3 - TIMER_A3
- tlv
- TLV
- wdt_a
- WDT_A
Structs
- ADC14
- ADC14
- AES256
- AES256
- CAPTIO0
- CAPTIO0
- CAPTIO1
- CAPTIO1
- CBP
- Cache and branch predictor maintenance operations
- COMP_E0
- COMP_E0
- COMP_E1
- COMP_E1
- CPUID
- CPUID
- CRC32
- CRC32
- CS
- CS
- Core
Peripherals - Core peripherals
- DCB
- Debug Control Block
- DIO
- DIO
- DMA
- DMA
- DWT
- Data Watchpoint and Trace unit
- EUSCI_
A0 - EUSCI_A0
- EUSCI_
A1 - EUSCI_A1
- EUSCI_
A2 - EUSCI_A2
- EUSCI_
A3 - EUSCI_A3
- EUSCI_
B0 - EUSCI_B0
- EUSCI_
B1 - EUSCI_B1
- EUSCI_
B2 - EUSCI_B2
- EUSCI_
B3 - EUSCI_B3
- FLCTL
- FLCTL
- FPB
- Flash Patch and Breakpoint unit
- FPU
- Floating Point Unit
- ITM
- Instrumentation Trace Macrocell
- MPU
- Memory Protection Unit
- NVIC
- Nested Vector Interrupt Controller
- PCM
- PCM
- PMAP
- PMAP
- PSS
- PSS
- Peripherals
- All the peripherals
- REF_A
- REF_A
- RSTCTL
- RSTCTL
- RTC_C
- RTC_C
- SCB
- System Control Block
- SYSCTL
- SYSCTL
- SYST
- SysTick: System Timer
- SYSTEMCONTROLSPACE
- System Control Space for ARM core: SCnSCB, SCB, SysTick, NVIC, CoreDebug, MPU, FPU
- TIMER32
- TIMER32
- TIMER_
A0 - TIMER_A0
- TIMER_
A1 - TIMER_A1
- TIMER_
A2 - TIMER_A2
- TIMER_
A3 - TIMER_A3
- TLV
- TLV
- TPIU
- Trace Port Interface Unit
- WDT_A
- WDT_A
Enums
- Interrupt
- Enumeration of all the interrupts.